# Release History

## 2.0.0 (2026-06-25)

### Features Added

  - Model `HierarchySettings` added property `system_data`
  - Model `ManagementGroup` added property `system_data`
  - Enum `ManagementGroupChildType` added member `SUBSCRIPTIONS`
  - Model `Operation` added property `is_data_action`
  - Model `Operation` added property `origin`
  - Model `Operation` added property `action_type`
  - Model `SubscriptionUnderManagementGroup` added property `system_data`
  - Added enum `ActionType`
  - Added enum `CreatedByType`
  - Added model `ErrorAdditionalInfo`
  - Added model `ErrorDetail`
  - Added model `OperationDisplay`
  - Added enum `Origin`
  - Added model `ProxyResource`
  - Added model `Resource`
  - Added model `SystemData`

### Breaking Changes

  - This version introduces new hybrid models which have dual dictionary and model nature. Please follow https://aka.ms/azsdk/python/migrate/hybrid-models for migration.
  - For the method breakings, please refer to https://aka.ms/azsdk/python/migrate/operations for migration.
  - Renamed client `ManagementGroupsAPI` to `ManagementGroupsMgmtClient`
  - Model `CreateManagementGroupRequest` moved instance variable `tenant_id`, `display_name`, `details` and `children` under property `properties` whose type is `CreateManagementGroupProperties`
  - Model `CreateOrUpdateSettingsRequest` moved instance variable `require_authorization_for_group_creation` and `default_management_group` under property `properties` whose type is `CreateOrUpdateSettingsProperties`
  - Model `DescendantInfo` moved instance variable `display_name` and `parent` under property `properties` whose type is `DescendantInfoProperties`
  - Model `EntityInfo` moved instance variable `tenant_id`, `display_name`, `parent`, `permissions`, `inherited_permissions`, `number_of_descendants`, `number_of_children`, `number_of_child_groups`, `parent_display_name_chain` and `parent_name_chain` under property `properties` whose type is `EntityInfoProperties`
  - Model `HierarchySettings` moved instance variable `tenant_id`, `require_authorization_for_group_creation` and `default_management_group` under property `properties` whose type is `HierarchySettingsProperties`
  - Model `HierarchySettingsInfo` moved instance variable `tenant_id`, `require_authorization_for_group_creation` and `default_management_group` under property `properties` whose type is `HierarchySettingsProperties`
  - Model `ManagementGroup` moved instance variable `tenant_id`, `display_name`, `details` and `children` under property `properties` whose type is `ManagementGroupProperties`
  - Model `ManagementGroupInfo` moved instance variable `tenant_id` and `display_name` under property `properties` whose type is `ManagementGroupInfoProperties`
  - Model `SubscriptionUnderManagementGroup` moved instance variable `tenant`, `display_name`, `parent` and `state` under property `properties` whose type is `SubscriptionUnderManagementGroupProperties`
  - Deleted or renamed model `AzureAsyncOperationResults`
  - Deleted or renamed model `EntityHierarchyItem`
  - Deleted or renamed model `ErrorDetails`
  - Deleted or renamed model `OperationDisplayProperties`
  - Deleted or renamed model `OperationResults`
  - Method `EntitiesOperations.list` changed its parameter `skiptoken`/`select`/`search`/`view`/`group_name`/`cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupSubscriptionsOperations.create` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupSubscriptionsOperations.delete` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupSubscriptionsOperations.get_subscription` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupSubscriptionsOperations.get_subscriptions_under_management_group` changed its parameter `skiptoken` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.begin_create_or_update` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.begin_delete` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.get` changed its parameter `expand`/`recurse`/`cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.get_descendants` changed its parameter `skiptoken` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.list` changed its parameter `cache_control`/`skiptoken` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.update` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.begin_delete` changed return type from `LROPoller[AzureAsyncOperationResults]` to `LROPoller[None]`

### Other Changes

  - Deleted model `DescendantListResult`/`EntityListResult`/`ListSubscriptionUnderManagementGroup`/`ManagementGroupListResult`/`OperationListResult` which actually were not used by SDK users

## 2.0.0b1 (2026-04-02)

### Features Added

  - Model `HierarchySettings` added property `system_data`
  - Model `ManagementGroup` added property `system_data`
  - Enum `ManagementGroupChildType` added member `SUBSCRIPTIONS`
  - Model `Operation` added property `is_data_action`
  - Model `Operation` added property `origin`
  - Model `Operation` added property `action_type`
  - Model `SubscriptionUnderManagementGroup` added property `system_data`
  - Added enum `ActionType`
  - Added enum `CreatedByType`
  - Added model `ErrorAdditionalInfo`
  - Added model `ErrorDetail`
  - Added model `OperationDisplay`
  - Added enum `Origin`
  - Added model `ProxyResource`
  - Added model `Resource`
  - Added model `SystemData`

### Breaking Changes

  - This version introduces new hybrid models which have dual dictionary and model nature. Please follow https://aka.ms/azsdk/python/migrate/hybrid-models for migration.
  - For the method breakings, please refer to https://aka.ms/azsdk/python/migrate/operations for migration.
  - Renamed client `ManagementGroupsAPI` to `ManagementGroupsMgmtClient`
  - Model `CreateManagementGroupRequest` moved instance variable `tenant_id`, `display_name`, `details` and `children` under property `properties` whose type is `CreateManagementGroupProperties`
  - Model `CreateOrUpdateSettingsRequest` moved instance variable `require_authorization_for_group_creation` and `default_management_group` under property `properties` whose type is `CreateOrUpdateSettingsProperties`
  - Model `HierarchySettingsInfo` moved instance variable `tenant_id`, `require_authorization_for_group_creation` and `default_management_group` under property `properties` whose type is `HierarchySettingsProperties`
  - Deleted or renamed model `AzureAsyncOperationResults`
  - Deleted or renamed model `EntityHierarchyItem`
  - Deleted or renamed model `ErrorDetails`
  - Deleted or renamed model `OperationDisplayProperties`
  - Deleted or renamed model `OperationResults`
  - Method `EntitiesOperations.list` changed its parameter `skiptoken`/`select`/`search`/`view`/`group_name`/`cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupSubscriptionsOperations.create` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupSubscriptionsOperations.delete` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupSubscriptionsOperations.get_subscription` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupSubscriptionsOperations.get_subscriptions_under_management_group` changed its parameter `skiptoken` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.begin_create_or_update` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.begin_delete` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.get` changed its parameter `expand`/`recurse`/`cache_control` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.get_descendants` changed its parameter `skiptoken` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.list` changed its parameter `cache_control`/`skiptoken` from `positional_or_keyword` to `keyword_only`
  - Method `ManagementGroupsOperations.update` changed its parameter `cache_control` from `positional_or_keyword` to `keyword_only`

### Other Changes

  - Deleted model `ListSubscriptionUnderManagementGroup` which actually was not used by SDK users

## 1.1.0 (2026-02-12)

### Bugs Fixed

  - Fixed import error when upgrading to latest azure-core

### Other Changes

  - Refreshed SDK code with latest code generator

## 1.1.0b2 (2024-11-05)

### Other Changes

  - Update dependencies

## 1.1.0b1 (2022-11-01)

### Features Added

  - Added model EntitySearchType
  - Added model EntityViewParameterType
  - Added model ManagementGroupExpandType
  - Added model ParentGroupBagInfo

## 1.0.0 (2021-05-21)

**Features**

  - Model ManagementGroupDetails has a new parameter path
  - Model ManagementGroupDetails has a new parameter management_group_ancestors
  - Model ManagementGroupDetails has a new parameter management_group_ancestors_chain

**Breaking changes**

  - Operation ManagementGroupSubscriptionsOperations.get_subscriptions_under_management_group has a new signature
  - Operation ManagementGroupsOperations.list has a new signature
  - Operation EntitiesOperations.list has a new signature
  - Operation ManagementGroupsOperations.get_descendants has a new signature
  - Model ManagementGroup no longer has parameter path

## 1.0.0b1 (2020-12-09)

This is beta preview version.

This version uses a next-generation code generator that introduces important breaking changes, but also important new features (like unified authentication and async programming).

**General breaking changes**

- Credential system has been completly revamped:

  - `azure.common.credentials` or `msrestazure.azure_active_directory` instances are no longer supported, use the `azure-identity` classes instead: https://pypi.org/project/azure-identity/
  - `credentials` parameter has been renamed `credential`

- The `config` attribute no longer exists on a client, configuration should be passed as kwarg. Example: `MyClient(credential, subscription_id, enable_logging=True)`. For a complete set of
  supported options, see the [parameters accept in init documentation of azure-core](https://github.com/Azure/azure-sdk-for-python/blob/main/sdk/core/azure-core/CLIENT_LIBRARY_DEVELOPER.md#available-policies)
- You can't import a `version` module anymore, use `__version__` instead
- Operations that used to return a `msrest.polling.LROPoller` now returns a `azure.core.polling.LROPoller` and are prefixed with `begin_`.
- Exceptions tree have been simplified and most exceptions are now `azure.core.exceptions.HttpResponseError` (`CloudError` has been removed).
- Most of the operation kwarg have changed. Some of the most noticeable:

  - `raw` has been removed. Equivalent feature can be found using `cls`, a callback that will give access to internal HTTP response for advanced user
  - For a complete set of
  supported options, see the [parameters accept in Request documentation of azure-core](https://github.com/Azure/azure-sdk-for-python/blob/main/sdk/core/azure-core/CLIENT_LIBRARY_DEVELOPER.md#available-policies)

**General new features**

- Type annotations support using `typing`. SDKs are mypy ready.
- This client has now stable and official support for async. Check the `aio` namespace of your package to find the async client.
- This client now support natively tracing library like OpenCensus or OpenTelemetry. See this [tracing quickstart](https://github.com/Azure/azure-sdk-for-python/tree/main/sdk/core/azure-core-tracing-opentelemetry) for an overview.

## 0.2.0 (2019-02-21)

**Features**

  - Model EntityInfo has a new parameter number_of_children
  - Model EntityInfo has a new parameter number_of_child_groups

## 0.1.0 (2018-05-31)

  - Initial Release
